@@ -30,6 +30,13 @@ cd "${MAIN_DIR}" || exit 1
 go get .
 cd "${OLDPWD}" || exit 1
 
+MIGRATE_DIR="${TEMP_DIR}/cmd/icingadb-migrate"
+
+echo "Getting migrate dependencies into: ${GOPATH}"
+cd "${MIGRATE_DIR}" || exit 1
+go get .
+cd "${OLDPWD}" || exit 1
+
 #TESTS_DIR="${TEMP_DIR}/tests"
 #
 #echo "Getting test dependencies into: ${GOPATH}"
